#
# spec file for package rtl_433
#
# Copyright (c) 2024 SUSE LLC
# Copyright (c) 2017-2024, Martin Hauke <mardnh@gmx.de>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           rtl_433
Version:        24.10
Release:        1.2
Summary:        Application turning the RTL2832 dongle into a 433.92MHz generic data receiver
License:        GPL-2.0-only
Group:          Productivity/Hamradio/Other
URL:            https://github.com/merbanan/rtl_433.git
Source:         https://github.com/merbanan/rtl_433/archive/refs/tags/%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  cmake
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(SoapySDR)
BuildRequires:  pkgconfig(librtlsdr)
BuildRequires:  pkgconfig(libusb)
BuildRequires:  pkgconfig(openssl)

%description
An application using librtlsdr to decode the temperature from
wireless temperature sensors (433.92MHz)

%package devel
Summary:        Header files for the RTL2832 dongle library
Group:          Development/Libraries/C and C++
Requires:       %{name} = %{version}

%description devel
Turns RTL2832 dongle into a 433.92MHz generic data receiver.

This subpackage contains header files for developing applications that want
to make use of rtl_433.

%prep
%setup -q

%build
%cmake \
    -DBUILD_TESTING=OFF
%cmake_build

%install
%cmake_install

%files
%license COPYING
%doc AUTHORS README.md
%{_bindir}/rtl_433
%dir %{_sysconfdir}/rtl_433
%config %{_sysconfdir}/rtl_433/*.conf
%{_mandir}/man1/rtl_433.1%{?ext_man}

%files devel
%{_includedir}/rtl_433.h
%{_includedir}/rtl_433_devices.h

%changelog
* Wed Oct 30 2024 Martin Hauke <mardnh@gmx.de>
- Update to version 24.10
  Breaking Changes
  * Changed to pm_2_5_ug_m3, pm_10_ug_m3, BREAKING change to
    Bresser-7in1.
  * Changed Smoke-GS558, Akhan-100F14 to default disabled.
  * Changed distance_km to storm_dist_km, BREAKING change to
    Bresser-Lightning.
  Highlights
  * Added support for Technoline TX960 to Acurite-606TX decoder.
  * Added support for Risco 2 way Agility protocol, Risco PIR/PET
    Sensor RWX95PA.
  * Added support for Rosstech Digital Control Unit
    DCU-706/Sundance/Jacuzzi.
  * Added support for Arexx Multilogger.
  * Updated Fineoffset-WS90 to new FW timings.
  * Added decoder conf for oma blind remote.
  * Added decoder conf for iVac Pro remote.
  * Added Vevor Weather Station 7-in-1.
  * Added support for Ecowitt WH46 air quality sensor.
  * Added open in browser script.
  * Added decoder conf for Hornbach MSRC-SAL Awning remote.
  * Added support for Geevon TX16-3 outdoor sensor.
  * Added support for Arad Master Meter water utility meter.
  * Added support for ThermoPro TP829b and Improve
    rtl_433_mqtt_hass.py.
  * Added Support for Chamberlain CWPIRC pir sensor.
  * Added support for Nice One to Nice-FlorS.
  * Added Support for Ecowitt WN34D and improve FineOffset WN34.
  * Added decoder conf for rolleaseacmedia blind controller.
  * Added decoder conf for Thomson kinetic doorbell.
  * Added ST389 temperature sensor for ORIA WA50 freezer
    thermometer.
  * Added decoder conf for Dewenwils BH-V.
  * Added Support BMW Gen3 TPMS.
  * Added decoder conf for self powered QX-305 & QX-302 switches.
  * Improved BMW Gen4-Gen5 TPMS and Add Support Audi TPMS Pressure
    Alert.
  * Added support for Audi TPMS and BMW Gen4 TPMS.
  * Added support for ThermoPro TP28b.
  * Added Support for Mueller Hot Rod water meter.
  * Added Support for Thermor DG950 Weather Station.
  * Added darker colors for light terminal backgrounds.
  * Added support for Watts WFHT-RF thermostat.
  * Added honor the NO_COLOR env var.
  * Added RTL433_COLOR=always/never/auto env var.
  * Added support for BMW Gen5 TPMS multi-brand HUF, Continental,
    Schrader/Sensata.
  * Added support for Bresser CO2 PN 7009977 and HCHO/VOC
    PN 7009978 sensors.
  * Added support for Fine Offset WN32B.
  * Added support for Fine Offset / Ecowitt WH55 water leak sensor
  * Added support for TechniSat IMETEO X6 and improve Holman-AOK.
  * Added Motonet MTX, MarQuant Rain note to Schou-72543.
  Changed
  * Added extract_bytes_uart_parity utility function.
  * Fixed Acurite-590TX timings.
  * Changed rtl_433_mqtt_hass.py to add supercap_V key.
  * examples: Added dup filtering to mqtt_relay.
  * Fixed wmbus raw data output length.
  * examples: Added ability for mqtt_relay to use a config file.
  * Added MQTT dedup republish filter example.
  * Added TX-Button to inFactory-TH.
  * examples: Changed mqtt_relay to always use id in topic.
  * examples: Improved mqtt_relay to make individual and json
    topics optional.
  * examples: Removed obsolete sigrok example scripts.
  * Changed Klimalogg-Pro max humidity.
  * Changed to type-safe data_append alternative.
  * Fixed rain_rate_in_h template in HA script.
  * Improved Ecowitt WH53.
  * Fixed Bresser-5in1 omit temp/hum on error.
  * Improved Wireless-MBus 3of6 decoding.
  * Added HA script compat for paho-mqtt 2.0.0 via legacy
    callback API.
  * Fixed Nissan TPMS pressure_PSI key.
  * Changed HA script power to energy and UV index to float.
  * Fixed Cotech-367959 lux and uv value.
  * Fixed TPMS Nissan pressure_psi value.
  * Fixed Bresser-6in1 rain vs temp.
  * Changed a HA script device trigger to avoid duplicate trigger.
  * Added some known fields to Marlec-Solar.
  * Added log rotate support for dumper files.
  * Added contact_open reed_open mappings to rtl_433_mqtt_hass.py
  * Added microseconds to OOK pulse data outputs.
  * Added OpenMetrics/Prometheus API.
  * Added strict checks to flex argument parsing.
  * Fixed EcoWitt-WS68 wind unit and decoding.
  * Fixed event callback on shutdown.
  * Fixed Badger-ORION return on decode success.
  * Improved Bresser lightning correct msg length and lfsr digest
    check.
  * Improved FS20 decoding, add FHT support.
  * Fixed properly install to /etc for /usr prefix.
  * Added compatible model TST-507 TPMS to EezTire E618.
  * Fixed Bresser-7in1 to exclude unavailable sensor values.
  * Added HTTP cmd API examples.
  * Fixed TPMS Elantra2012 for longer desync.
  * Fixed KlikAanKlikUit-Switch for DIO remotes.
  * Fixed rtl_433_mqtt_hass.py rain_in value template.
  * Fixed Bresser-Lightning decoding of 'count'.
  * Fixed detection of Bresser-ProRainGauge.
  * Improved EcoWitt-WS68 LUX and UVI decoding and add units.
  * Fixed Fineoffset-WS90 to support newer firmware.
  * Added Ecowitt air quality sensors to rtl_433_mqtt_hass.py.
  * Added mqtt base topic option.
  * Added reading mqtt auth from env vars.
  * Fixed converting inches to mm.
  * Changed rtl_433_mqtt_hass.py to support storm_dist_km from
    WH31L.
  * Added channel/button to Acurite-606TX.
  * Fixed TFA-303151 negative temps.
  * Fixed temperature for Bresser 3-in-1 Wind Gauge.
  * Improved code and annotations for cpplint.
* Wed Nov 29 2023 Martin Hauke <mardnh@gmx.de>
- Update to version 23.11
  Breaking Changes
  * Changed conf dir defaults to just SYSCONFDIR.
  * Changed verbosity of Protocols Registered output.
  * Changed example conf file to use defaults.
  * Changed help texts to print to stdout.
  * Fixed Oregon Scientific channel renumbering, BREAKING change
    to THN132N channel 3.
  * Changed MQTT client ID to contain all params.
  * Fixed GEO-minim matching, BREAKING change to id field.
  * Changed Inkbird-ITH20R temperature2_C to temperature_2_C
    BREAKING change.
  Highlights
  * Added support for Schou 72543 rain sensor
  * Added support for Bresser Lightning and Bresser Air Quality.
  * Added support for Tekelek oil gauge
  * Added support for Nissan Leaf TPMS.
  * Added support for Carchet TPMS.
  * Added support for Bresser water leakage sensor PN: 7009975.
  * Added support for discovering Govee water sensors to
    rtl_433_mqtt_hass.
  * Added support for newer Chuango DWC-102 close command.
  * Added support for TFA Stratos 30.3151 and improve Fineoffset
    WH1050.
  * Added support for IROX ETS69 to Ewig Emos-TTX201.
  * Added support for ThermoPro TX-2C.
  * Added support for Fineoffset WS90.
  * Added support for Acurite 592TX.
  * Added support for Oregon Scientific AWR129 BBQ thermometer.
  * Added support for Celsia CZC1.
  * Added support for Baldr/Rainpoint rain gauge.
  * Added support for EezTire-E618 TPMS10ATC.
  * Added support for LaCrosse TX31U-IT.
  * Added support for Revolt Energy Monitor NC-5462.
  * Added support for Emax EM3551H with Gust without UV/Lux to
    Emax-W6.
  * Added support for Wireless M-Bus Mode T Downlink.
  * Added support for Gasmate-BA1008.
  * Added support for Oil-SonicSmart.
  * Added support for Watchman Sonic Advanced / Plus decoder.
  * Added support for CED7000 timer.
  * Added support for Emax Weather Sensor, improves Altronics X7064
    sensor.
  * Added support for TFA Dostmann 14.1504 Radio-controlled grill
    and meat thermometer.
  * Added support for new revision of Govee H5054 water leak
    detector.
  * Added support for Vauno EN8822C.
  * Added support for WEC-2103 temperature/humidity sensor.
  * Added support for Neptune R900 flow meters.
  * Added support for SRSmith SRS-2C-TX Pool Remote Control.
  * Added support for Kia Rio III (UB) and Hyundai TPMS sensors.
  * Added support for TyreGuard 400 TPMS.
  * Added support for GEO minim+ energy monitor.
  * Added support for longer EFTH800 messages.
  * Added decoder conf for PHOX garage gate opener.
  * Added decoder conf for Driveway alarm motion sensor I8-W1901.
  * Added decoder conf for Reolink doorbell.
  * Added decoder conf for SWETUP garage door remote.
  * Added decoder conf for ELRO AB440 remote.
  * Added decoder conf for xmas tree remote 2APJZ-CW002.
  * Added decoder conf for GE Smartremote Plus.
  * Added standardized detect key for Govee-Water.
  * Added restartable SDR device.
  * Changed to async SDR acquire thread.
  * Changed to second Ctrl-C is a hard abort.
  * Added log output, log redirect, colored KV log.
  Changed
  * Changed rtl_433_mqtt_hass.py to use moisture class.
  * Changed rtl_433_mqtt_hass.py to add battery_mV.
  * Changed Fineoffset-WS90 packet size check.
  * Fixed logging message in HA script.
  * Added Pool/Spa Thermometer PN 7009973 note to Bresser-6in1.
  * Added php example stream script.
  * Added checksum and battery_ok to WEC-2103.
  * Changed version number to exclude nightly tag.
  * Changed EezTire-E618 checksum, include flags.
  * Changed startup help text to the actual help page.
  * Improved some strcpy strncpy to snprintf.
  * Improved all plain sprintf to snprintf.
  * Fixed Somfy-IOHC length check.
  * Added warning if firewall blocks loopback.
  * Improved HA script with precipitation and wind speed class.
  * Fixed Honeywell-CM921 temperature msg.
  * Added Lidl Auriol 4-LD6313 and 4-LD5972 temperature/rain sensor.
  * Improved HA script with current class.
  * Improved handling of units within HA UI.
  * Improved HA script with detailed units.
  * Fixed HA script allow list id typo.
  * Fixed Fineoffset-WH1050 return value.
  * Fixed Inkbird-ITH20R battery_ok key and range.
  * Fixed HA script remove device name from entities.
  * Fixed HA script topics.
  * Fixed malformed json on empty row print.
  * Fixed Ecowitt-WS90 extra data output.
  * Added description of startup bit to Bresser-5in1.
  * Fixed various spelling.
  * Added lower temp bounds to Acurite-5n1, Acurite-Atlas.
  * Added humidity_1, humidity_2 to rtl_433_mqtt_hass.
  * Added timestamp to logs in rtl_433_mqtt_hass.
  * Fixed HASS script rain_rate_mm_h typo.
  * Fixed Eurochron-EFTH800 radio_clock hour decoding.
  * Changed Fineoffset-WS90 to add firmware version.
  * Changed ThermoPro TX-2C to enable humidity.
  * Added radio clock to Fineoffset-WH1050.
  * Added battery voltage to EcoWitt-WH40.
  * Changed EMOS-E6016 wind speed and battery.
  * Improved Holman ws5029, Add support for AOK-5056 and correction
    for Emax.
  * Fixed current frequency and sample rate info.
  * Changed rtl_433_mqtt_hass to enable passing custom topics.
  * Added extra digit to Oregon Scientific for AWR129.
  * Changed Acurite 896 rain gauge to default enabled.
  * Changed CM160 output to double.
  * Fixed CM160 energy calculation factor.
  * Changed r_device.fields to constant pointer.
  * Added total energy kWh to CM160 readings.
  * Fixed Fitipower FC0012 gain quirk.
  * Added unlockable rtl_tcp control.
  * Fixed rtl_tcp for slow send buffers.
  * Fixed Oil-SonicAdv missing messages.
  * Fixed LaCrosse-R1/LaCrosse-R3 rain value.
  * Added char const check to symbolizer.
  * Fixed flowis protocol decoding, alarm and back flow parameters.
  * Changed literals to string const for strict
    discarded-qualifiers warnings.
  * Added Schrader 3039 TPMS for Infiniti Nissan Renault note to
    Schrader-SMD3MA4.
  * Fixed Emax units.
  * Added TLS debug info for influxs and mqtts.
  * Fixed Emax LUX decoding.
  * Fixed Vauno-EN8822C false positives.
  * Added Flowis protocol decoder.
  * Added Wireless M-Bus, Mode T Downlink.
  * Fixed out-of-bounds in Klimalogg-Pro.
  * Fixed Somfy-RTS for wrong bitrate.
  * Changed all r_device declarations to const.
  * Fixed pointer restrict for C++ compilers.
  * Fixed TFA-141504v2 decoder length check.
  * Added radio clock decode to Eurochron-EFTH800.
  * Changed Somfy-IOHC to recognize more messages.
  * Fixed Oregon Scientific negative temp, add BCD sanity checks.
  * Added ESIC/SCMplus fields to rtl_433_mqtt_hass.
  * Changed LaCrosse TX invalid humidity handling.
  * Fixed json keys for wmbus to be unique.
  * Fixed Bresser-ProRainGauge rain digits.
  * Fixed light reading on Cotech-367959 when no sensor installed.
  * Fixed HCS200 serial ID decoding.
  * Added TLS options to InfluxDB output.
  * Added output log level options.
  * Fixed battery flag in AmbientWeather-WH31E/WH31B.
  * Changed more fprintf to log prints.
  * Changed fprintf to log prints.
  * Changed verbosity to match log level.
  * Added basic logger.
  * Fixed JSON output string escaping.
  * Added decode_dm flex option.
* Sat Nov 19 2022 Martin Hauke <mardnh@gmx.de>
- Update to version 22.11
  Breaking Changes
  * Fixed irregular model names.
    "Inkbird ITH-20R" -> "Inkbird-ITH20R"
    "LaCrosse-WS7000-27/28" -> "LaCrosse-WS700027"
    "LaCrosse-WS7000-22/25" -> "LaCrosse-WS700022"
    "LaCrosse-WS7000-16" -> "LaCrosse-WS700016"
    "LaCrosse-WS7000-15" -> "LaCrosse-WS700015"
    "LaCrosse-WS7000-20" -> "LaCrosse-WS700020"
    "LaCrosse-WS2500-19" -> "LaCrosse-WS250019"
    "Abarth 124 Spider" -> "Abarth-124Spider"
    "Jansite Solar" -> "Jansite-Solar"
    "Klimalogg Pro" -> "Klimalogg-Pro"
    "Secplus_v1" -> "Secplus-v1"
    "SCM+" -> "SCMplus"
    Changed light_klx to light_lux in Bresser-7in1.
  Highlights
  * Added rtl_tcp pass-through output.
  * Added realtime replay option for file inputs.
  * Added support for Badger ORION water meter.
  * Added support for Rubicson pool thermometer.
  * Added support for Fine Offset WN34 temperature sensor.
  * Added support for KS200/KS300 to ELV WS2000.
  * Added support for Maverick XR-30.
  * Added support for Fine Offset WH45 air quality sensor.
  * Added support for HCS200/HCS300 based remotes with FSK
    transmitters.
  * Added support for Emos E6016 Rain Gauge.
  * Added support for ANT and ANT+ devices.
  * Added support for Altronics X7064 sensor.
  * Added support for EMOS 6016.
  * Added support for FineOffset WS80 weather station.
  * Added support for Renault-0435R TPMS.
  * Added support for AcuRite 01190 Leak Detector.
  * Added support for Regency ceiling fans.
  * Added support for Microchip HCS300 KeeLoq remotes.
  * Added support for Yale HSA.
  * Added support for SimpliSafe-Gen3.
  * Added support for AVE TPMS.
  * Added decoder conf for sgooway door detector.
  * Added decoder conf for ContinentalRemote.
  * Added decoder conf for Mondeo remote.
  * Added decoder conf for LeakDetector.
  * Added decoder conf for Heatilator-Gas-Log.
  * Added decoder conf for Honeywell-Fan.
  * Added decoder conf for DrivewayAlert.
  * Added decoder conf for GhostControls.
  * Added Threads if available.
  Changed
  * Added note regarding WH51 915MHz decoding.
  * Added publish secret knocks as device automations.
  * Added time, channel, and button device automation triggers.
  * Improved false positives for acurite_01185m.
  * Changed rtl_433_mqtt_hass rain value template round to two
    digits.
  * Changed rtl_433_mqtt_hass value templates round to one digit.
  * Fixed Chuango devices with some zeroes in their ID.
  * Changed Proove/Nexa/Kaku to support Smartwares SH4-90152.
  * Changed Acurite TXR decoder to improve validation.
  * Fixed Efergy-e2CT current above 53 Amp.
  * Added sanity check to Ambient Weather F007th.
  * Added decode symbol helper and flex option.
  * Added InFactory PT-310 support to Rubicson.
  * Added HTTP API example scripts.
  * Changed rain gauge multiplier for Auriol-4LD5661.
  * Added CSV names for flex getters with unique mode.
  * Added php example script.
  * Improved Ford TPMS decoder.
  * Fixed crash when reading a conf file.
  * Changed SDR data buffers to persist valid.
  * Added ERT-SCM consumption data to mqtt hass mappings.
  * Added id filter to mqtt hass.
  * Fixed overflow in Acurite-00275rm.
  * Changed the PCM/NRZ/RZ naming.
  * Added cmake option to select IPv6 support.
  * Fixed EMOS-6016 checksum, add DCF77.
  * Added bitbuffer_find_repeated_prefix function.
  * Fixed pulse reset on spurious pulses.
  * Removed confusing -G register all option.
  * Changed hass script duplicate dict key 'light_lux' back to 'lux'
    for legacy reasons.
  * Added Honeywell-cm921 Ticker and Heat Demand commands.
  * Changed most decoder-verbose to log level.
  * Changed fprintf in decoders to decoder_log.
  * Added decoder log to replace bitbuffer bitrow print.
  * Added decoder log to replace fprintf.
  * Fixed Digitech-XC0324 humidity readings (FT-005TH Sensor).
  * Changed wt0124 to use additional checksum.
  * Added diagnostic entity category to mqtt hass example.
  * Removed invalid "weather" device class in HASS script.
  * Added trigger stream output.
  * Changed Hideki to accept short sync.
- Drop patch:
  0001-Fix-overflow-in-Acurite-00275rm-closes-2012.patch
* Wed Apr 13 2022 Martin Hauke <mardnh@gmx.de>
- Add patch to fix security issue: CVE-2022-27419 (bsc#1198434)
  * 0001-Fix-overflow-in-Acurite-00275rm-closes-2012.patch
* Thu Dec 16 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 21.12
  Highlights
  * Added noise stats, autolevel, and squelch
  * Added automatic file format detection from filename
  * Added support for SmartFire Proflame 2 remote control
  * Added support for Lacrosse TX34 rain gauge
  * Added support for Telldus-FT0385R
  * Added support for GE Choice Alert wireless alarm sensors
  * Added support for Porsche Boxter/Cayman TPMS
  * Added support for Funkbus/Instafunk
  * Added support for Truck TPMS
  * Added support for LaCrosse LTV-W1 wind sensor
  * Added support for Auriol 4-LD5661 temperature/rain sensor
  * Added support for Linear Megacode Remote
  * Added support for EnOcean ERP1 decoder
  * Added support for Acurite-01185M
  * Added support for ATech-WS308 temperature sensor
  * Added support for RainPoint sensor
  * Added support for Inkbird ITH-20R
  * Added support for Clipsal CMR112 cent-a-meter power meter
  * Added support for Govee Water Leak Detector H5054 and Govee
    Contact Sensor B5023
  * Added support for Markisol curtain remote
  * Added support for Oregon Scientific BTHR918
  * Added UV index add decimals to Bresser-7in1
  * Changed InfluxDB output of 'mic' from field to tag
  * Added biastee, digital_agc, direct_samp, offset_tune option
    for rtlsdr and rtl_tcp
  * Added QoS to MQTT options
  Changed
  * Changed PCM slicer to measure bit length in more cases
  * Added CS8 as file input format
  * Added decoder priority stages
  * Fixed fprintf to use an unsigned marker when an unsigned value
    is given
  * Added RTL_433_REDUCE_STACK_USE to reduce size of bitbuffers
  * Fixed rainpoint msg buffer must be initialized
  * Fixed Reduce stack use in slicers
  * Changed HASS script to logging
  * Added SwitchDocLabs SM23 note
  * Added SwitchDocLabs F016TH note
  * Added SwitchDocLabs FT020T note
  * Fixed Inovalley-kw9015b rain bits
  * Added battery_ok to Bresser-7in1
  * Added HASS long term statistics
  * Added bitbuffer row spill
  * Updated Govee Leak Sensor with new parity check
  * Fixed Springfield-Soil/AlectoV1 false positives
  * Fixed LaCrosse-TH3 checksum
  * Added cmake found lib versions output
* Mon May 10 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 21.05
  Highlights
  - Last release to support Autotools (autoconf, automake) builds
  - Last release to offer "oldmodel" keys (deprected since 2020)
  - Added GPSd tags option
  - Added optional TLS support to MQTT
  - Added OpenSSL support for influxs TLS
  - Added support for ELK-319DWM, Alula RE101 to Interlogix
  - Added conf for Tesla charge port opener
  - Added support for  Hyundai-VDO TPMS
  - Added support for TX25U dual channel temp sensor
  - Added support for Honeywell CM921/BDR91/Evohome
  - Added support for Auriol AFT 77 B2
  - Added support for Auriol AHFL
  - Added support for Bresser Professional Rain Gauge
  - Added support for TFA Marbella pool thermometer
  - Added support for Amazon Basics Meat Thermometer
  - Added support for Owl 180i support
  - Added support for Jansite TPMS Model Solar
  - Added support for Cavius alarms
  - Added support for Security plus v1
  - Added conf for Skylink HA-434TL motion sensor
  - Added support for Burnhard BBQ thermometer
  - Added support for wmbus water meter Maddalena
  - Added conf for ATC Technology LMT-430
  - Added support for Blueline PowerCost Monitor
  - Added conf for FAN-53T
  - Added support for Acurite 515 fridge/freezer sensors
  - Added support for TelFix-RadioLoop (#1571)
  - Added conf for Salus RT300RF thermostat, Heatmiser PRT-W
    thermostat
  Changes
  - Added pressure_kPa key for HA (#1712)
  - Added support for ELK-319DWM, Alula RE101 to Interlogix (closes #1711)
  - Fixed and style Honeywell CM921
  - Added option to set force_update for all sensors (#1695)
  - Added Tesla charge port opener decoder conf (#1704)
  - Added battery flags to Bresser 7in1 (closes #1703)
  - Fixed Hyundai-VDO TPMS
  - Added Hyundai-VDO TPMS (#1643)
  - Added X10 Dim, Bright, All Lights ON, and All Off commands (#1687)
  - Added support for TX25U dual channel temp sensor
  - Fixed code warnings
  - Fixed code style
  - Added forgotten id
  - Added Honeywell CM921/BDR91/Evohome decoder (#1336)
  - Added Auriol AFT 77 B2 protocol decoder
  - Fixed Holman-WS5029 rain count (#1686)
  - Fixed explanation of supposed PM10 (estimated) value (#1678)
  - Added support for Auriol AHFL protocol (#1683)
  - Fixed PSI calculation for Ford TPMS
  - Added support for higher pressure range in Ford TPMS
  - Fixed secplus_v1 endless loop (closes #1662)
  - Fixed secplus_v1 overflow
  - Added support for some Ecowitt WH41 sensor signals
  - Added comment regarding PM10 readings in the FineOffset WH0290 decoder
  - Added support for Bresser Professional Rain Gauge (#1676)
  - Added TFA Marbella pool thermometer protocol decoder (#1675)
  - Added Amazon Basics Meat Thermometer decoder (#1671)
  - Fixed exit if http server can't start
  - Added Owl 180i support
  - Added website and sensor specifications for Jansite TPMS Model Solar (#1666)
  - Added decoder for jansite solar tpms (#1663)
  - Added Ford TPMS pressure and temperature (closes #1654)
  - Fixed http redirect to index for Chrome
  - Added support for Cavius alarms (#1648)
  - Added mqtt token slash accepts any character
  - Added variable fm low pass filter option
  - Added support for Security plus v1 (#1483)
  - Added GPSd tags option (#1636)
  - Added FineOffset WH0290 extra fields (#1639)
  - Fixed Hideki Gust speed by Udo Kirsten
  - Added option for multiple data tags
  - Added optional TLS support to MQTT (closes #1633)
  - Added OpenSSL support for influxs TLS (closes #1569)
  - Added LaCrosse TX141TH-Bv2 checksum
  - Changed rain field format for WS2032
  - Added m_bus decoded values + HCA (#1630)
  - Changed battery_ok, rain field for WS2032
  - Fixed m_bus Show invalid dates as invalid (#1628)
  - Fixed mqtt retain on hass script (#1602)
  - Added Skylink HA-434TL motion sensor conf (s.a. #814)
  - Added support for Burnhard BBQ thermometer (#1624)
  - Added TFA 30.3208.02 note (closes #1622)
  - Added raw pulse printing mode
  - Added support for parsing timedate in wbus (#1616)
  - Added Battery Level for Fineoffset WH0290 Wireless Air Quality Monitor (#1617)
  - Fixed Blueline tweaks and improvements (#1590)
  - Added support for wmbus water meter Maddalena (#1610)
  - Changed soil moisture to percent display (#1595)
  - Added ATC Technology LMT-430 conf (#1600)
  - Fixed buffer length in honeywell (#1598)
  - Fixed buffer size error (#1596)
  - Fixed FineOffset WH1050 field widths (#1592)
  - Added support for Blueline PowerCost Monitor
  - Added FAN-53T decoder conf (#1588)
  - Added support for Acurite 515 fridge/freezer sensors (#1579)
  - Fixed invalid HASS "weather" device_class (#1548)
  - Fixed rtlsdr_read_async() abort on read stall (closes #1581)
  - Fixed rtlsdr_set_freq_correction non-error code
  - Added support for UV index and light intensity readings in Cotech (#1575)
  - Fixed false positive bug in Nexus (closes #1576)
  - Added support for TelFix-RadioLoop to Somfy (closes #1571)
  - Added Thermostat example conf files with mqtt outputs (#1573)
  - Added lacrosse decoder sanity checks
* Sat Nov 14 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 20.11
  Highlights
  * HTTP server, JSON-RPC
  * Added RfRaw analyzer output and format input support
  * Added support for LaCrosse Technology View LTV-R1 Rainfall Gauge
  * Added support for ECODHOME smart socket
  * Added support for LaCrosse Technology View TH2 Thermo/Hygro sensor
  * Added support for Bresser 6-in-1, 7-in-1 weather station
  * Added support for LaCrosse Technology View TH3 Thermo/Hygro Sensor
  * Added support for LaCrosse LTV-WR1 Multi Sensor
  * Added support for Nice Flor-s remote
  * Added support for Schrader TPMS SMD3MA4 (Subaru)
  * Added support for MightyMule Driveway Alarm FM231
  * Added support for Somfy RTS
  * Added support for LaCrosse LTV-WSDTH01
  * Added support for TFA 30.3221.02 Temperature/Humidity sensor
  * Added support for Security plus v2 keyfob
  * Added support for Acurite Atlas and Atlas Lightning Detector
  * Added support for Acurite 590TX
  * Added support for ThermoPro TX2
  * Added support for IDM and NetIDM decoders
  * Added support for Insteon decoder
  * Added support for LaCrosse TX141B
  * Added support for Sharp SPC775
  * Added support for Missil ML0757
  * Added support for Fineoffset WH32
  * Added support for Abarth124 TPMS sensor
  * Added support for Fine Offset WH1080 FSK version
  * Added support for SCM+ decoder
  * Added support for Kerui WD51 Water leak sensor
  * Added support for Cotech 36-7959
  * Added support for Eurochron EFTH-800
  * Added support for Visonic Powercode devices
  * Added support for Klimalogg decoder and needed nrzs demodulator
  Changed
  * Added support for LaCrosse Technology View R1 Rainfall Gauge (#1553)
  * Added http server (#871)
  * Added jsmn json lib
  * Added support for ECODHOME smart socket (#1544)
  * Fixed Lacrosse-THx hardcoded strings to support data extractor scripts
  * Added support for LaCrosse Technology View TH2 Thermo/Hygro sensor (#1552)
  * Added stats start time reporting
  * Fixed Analyzer FSK/OOK hint (#1557)
  * Improved unit tests for bitbuffer with extra assertions
  * Fixed UNUSED in term_ctl
  * Removed "http" as "influx" alias
  * Added arguments and docs to Home Assistant MQTT auto discovery script (#1546)
  * Changed LaCrosse LTV-WR1 to wind_avg_km_h key (#1549)
  * Fixed rfraw builder overflow (#1539)
  * Added Dooya Curtain Remote conf (#1545)
  * Added SDR loop api
  * Changed to sig_atomic_t for sighandler
  * Fixed wmbus csv output parameters
  * Fixed flags field for TPMS Jansite (#1538)
  * Added note for TFA Dostmann 30.3159.IT (#1537)
  * Added SDR runtime settings api
  * Changed exit async naming
  * Added SDR device info
  * Added support for Bresser 6-in-1, 7-in-1 weather station (#1225)
  * Added support for LaCrosse Technology View TH3 Thermo/Hygro Sensor (#1536)
  * Added support for LaCrosse LTV-WR1 Multi Sensor (#1533)
  * Added support for Nice Flor-s remote (#1526)
  * Changed remove DSC subtype key (#1522)
  * Changed Acurite subtype key to message_type (#1520)
  * Added support for WH31E RCC packet type (#1528)
  * Fixed wmbus mode S buffer length issue for Lansen meters
  * Added SoapySDR to MinGW-w64 build
  * Added output format option to flex getters (#1532)
  * Added TFA 30.3209 note to Nexus (#1516)
  * Added TFA-Dostmann 30.3161 rain scale (#1531)
  * Fixed Insteon string overflow
  * Fixed missing CSV fields, add a debug check
  * Added named output tag option (#1517)
  * Added support for Schrader TPMS SMD3MA4 (Subaru) (#1511)
  * Removed unneeded update_protocol
  * Changed width calc from r_device to slicers (#1513)
  * Added support for mightymule driveway alarm FM231 (#1407) (#1515)
  * Changed rfraw parse to accept multiple codes
  * Fixed include for memcmp in rfraw (#1507)
  * Added id key to scmplus (#1503)
  * Removed list of supported device protocols from man page (#1345)
  * Added RfRaw analyzer output support
  * Added RfRaw format input support
  * Removed FSK_PULSE_MANCHESTER_ZEROBIT from ook_demods
  * Fixed Inovalley kw9015b temp/rain fields proper
  * Fixed Inovalley kw9015b temp/rain fields (#1501)
  * Added support for Somfy RTS (#1496)
  * Added 7-bit clean strings check to actions
  * Added maintainer_update check
  * Fixed Security+ 2.0 decoder for new gap_limit rows (#1498)
  * Added clang-analyzer action
  * Added build action
  * Added style check action
  * Improved PCM NRZ 0-bit slicing precision
  * Fixed output keys for FineOffset WH51 (#1495)
  * Fixed index bug in TFA 30.3221
  * Fixed simplisafe non-printable character output
  * Added support for LaCrosse LTV-WSDTH01 (#1485)
  * Added gap_limit to PCM demod
  * Fixed invalid dumpers on ook input (#1463)
  * Added support for TFA 30.3221.02 Temperature/Humidity sensor (#1426)
  * Fixed Acurite 6045 temperature 2.0F too low (#1482 #1401)
  * Added support for Security plus v2 keyfob (#1480)
  * Fixed opus_xt300 added sanity check to data values (#1470)
  * Fixed runtime error 'left shift of 229 by 24 places cannot be represented in type int (#1479)
  * Fixed bad conf for Fan-11t (#1477)
  * Added came top432 flex decoder config (#1474)
  * Fixed wmbus raw telegram output, mainly for wmbusmeters use
  * Fixed efergy_e2_classic False Trigger (#1475)
  * FIXed check manchester_decode check decoded bit length in a constent method, removed superfluous comment
  * FIXed check manchester_decode result length
  * Fixed current_cost 8 bytes required
  * Fixed TPMS Abarth124 false positive (#1466)
  * Fixed alectov1 csv fields (#1457)
  * Added Atlas Lightning Detector support (#1418)
  * Added Acurite Atlas support (#1124)
  * Added Nexus-TE82s compatibility note (#1455)
  * Updated idm scmplus Meter type list (#1445)
  * Added Acurite 590TX support (#1411)
  * Added ThermoPro TX2 support (#1450)
  * Improved program exit code in case of error (#1451)
  * Improved Home Assistant MQTT auto discovery (#1390)
  * Fixed Many False Positives (#1444)
  * Fixed Globaltronics QUIGG GT-TMBBQ-05 false positives (#1443)
  * Fixed Oregon Scientific SL109H false positives (#1442)
  * Added IDM and NetIDM decoders (#1421)
  * Changed Fineoffset WH32 to exclude pressure
  * Added Insteon decoder (#1285)
  * Added Friedland EVO door bell conf
  * Added support for LaCrosse TX141B (#1434)
  * Added missing parts for Sharp SPC775 decoder
  * Added Sharp SPC775 support (#1433)
  * Added support for Missil ML0757
  * Fixed use of return code in Abarth Spider decoder
  * Added conditional to data_make (#1432)
  * Added support for Fineoffset WH32 (#1431)
  * Added bit reversed output for HCS200 decoder to match official tools
  * Added reverse32 function
  * Improved x10sec add sensors, tamper, crc (#1413)
  * Improved inFactory e.g. MIC (#1325)
  * Changed Kerui to break out additional fields from state (#1018)
  * Updated rtl_433.example.conf
  * Improved validations checks for smoke_gs558 protocol
  * Added Equation/Siemens ADLM FPRF remote conf
  * Added Abarth124 tpms sensor support
  * Added missing protocol to readme
  * Added attenuation histogram output (#1387)
  * Added Fine Offset WH1080 FSK version support
  * Improved FSK demodulation of distorted signals better
  * Added SCM+ decoder (#1410)
  * Added support for Kerui WD51 Water leak sensor (#1406)
  * Fixed cancel watchdog when reading from file input
  * Fixed ERT Endpoint Type extraction (#1379)
  * Added custom data processor example
  * Improved Honeywell sensor support (#1384)
  * Added delay and low battery codes for DS10A door sensor (#1397)
  * Fixed free results from SoapySDR API
  * Fixed handle empty filenames
  * Added support for Cotech 36-7959 (#1382)
  * Removed deprecated positional flex syntax
  * Changed div 10 to mul 0.1 in all decoders
  * Changed value scaling for double to float in all decoders
  * Changed checks on Rubicson/Nexus/Solight
  * Fixed Bresser 5in1 Wind calculation (#1353)
  * Improved MQTT Home Assistant example (#1357)
  * Added decode_uart util (#1376)
  * Fixed Eurochron EFTH-800 missing mic
  * Added Eurochron EFTH-800 support (#1375)
  * Fixed MQTTT mgr free
  * Fixed Soapy string leaks
  * Added Prometheus/OpenMetrics relay example (#1371)
  * Fixed missing levels with minmax demod (fixes #1363)
  * Fixed socket portability
  * Fixed visonic device battery reporting
  * Improved visonic_powercode
  * Fixed rtl_tcp gain/rate/freq status output
  * Fixed missing WSAStartup in rtl_tcp
  * Added support for Visonic Powercode devices (#1349)
  * Added message length check for ESIC EMT7110.
  * Updated Acurite 6045 to capture all 8 bits of strike counter (#1348)
  * Added configuration file for SMC5326 (#1346)
  * Updated template guideline for verbosity (#1344)
  * Fixed failing style-check test by adding allocation check to write-sigrok
  * Fixed flex map parse
  * Changed -l n to -Y level=n
  * Changed detector level limits to dB
  * Fixed Fineoffset-WHx080 temperature (#1327)
  * Fixed Ecowitt-WH53, Maverick-ET73 timings
  * Fixed Klimalogg device settings, tolerance was set to low
  * Added Klimalogg decoder and needed nrzs demodulator
  * Fixed negative temperatures in wmbus decoder
  * Added pulse-eval example
* Tue Feb 18 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 20.02+git.20200218:
  Highlights
  * Added InfluxDB output
  * Added native Sigrok writer
  * Changed to newmodel keys default
  * Fixed SoapySDR for 0.8 API
  * Added new minmax FSK pulse detector
  * Changed default to use new minmax detector and sample rate
    of 1MS/s for frequency above 800MHz
  * Changed -a and -G option to discourage usage
  * Improvements and support for many more sensors
- Build with support for SoapySDR
* Tue Sep 10 2019 Jan Engelhardt <jengelh@inai.de>
- Update descriptions.
* Fri Aug 30 2019 Martin Pluskal <mpluskal@suse.com>
- Use new macro for cmake building
* Thu Aug 29 2019 Martin Hauke <mardnh@gmx.de>
- Update to version 19.08+git.20190829:
  Highlights:
  * Added MQTT output (#1016)
  * Added stats reporting (#733)
  * Added SoapySDR general keyword settings option, e.g. antenna
  * Added new model keys option
  * Changed Normalize odd general keys on devices (#1010)
  * Changed Use battery_ok instead of battery for newmodel
  * Added report model description option (#987)
  * Added pulse data text file support (#967)
  * Added color to console help output
  * Fixed CF32 loader; addeded CS8, CF32 dumper
  Changes:
  * Added CurrentCost EnviR support (#1115)
  * Added ESIC-EMT7170 power meter (#1132)
  * Added LaCrosse-TX141Bv3 support (#1134)
  * Added channel to inFactory-TH (#1133)
  * Added man page rtl_433.1 (#1121)
  * Added color to console help output
  * Added support for Philips AJ7010 (#1047)
  * Added frequency hopping signal support for win32 (#1128)
  * Added Holman WS5029 decoder
  * Added Acurite Rain 899 support
  * Added support for Oregon scientific THGR328N and RTGR328N (#1107) (#1109)
  * Added frequency hop on USR1 signal
  * Added '-E hop' option
  * Added option for multiple hop times
  * Added sensor similar to GT-WT-02 (#1080)
  * Added Rubicson 48659 Cooking Thermometer
  * Added TFA Dostmann 30.3196 decoder (#983)
  * Added support for HCS200 KeeLoq encoder (#1081)
  * Added channel output to lacrosse_TX141TH_Bv2 (#1097)
  * Added IKEA Sparsnäs decoder.
  * Added support for Eurochron weather station sensor (#1090)
  * Added MQTT topic format strings (#1079)
  * Added two EV1527 based sample configurations (#1087)
  * Added DirecTV RC66RX Remote Control
  * Added support for Ecowitt temperature sensor
  * Added Companion WTR001 decoder (#1055)
  * Changed Thermopro TP12 also supports TP20 (#1061)
  * Added configuration for PIR-EF4 sensor (#1049)
  * Added Alecto WS-1200 v1/v2/DCF decoders to Fineoffset (#975)
  * Added TS-FT002 decoder (#1015)
  * Added Fine Offset WH32B support (#1040)
  * Added LaCrosse-WS3600 support, change LaCrosse-WS to LaCrosse-WS2310
  * Added LaCrosse WS7000 support (#1029) (#1030)
  * Changed Omit humidity on Prologue if invalid
  * Added MQTT output (#1016)
  * Added stats reporting (#733)
  * Added Interface Specification for data output (#827)
  * Added checksum to Ambient Weather TX-8300
  * Added Interlogix glassbreak subtype
  * Added Jansite TPMS support (#1020)
  * Added Oregon Scientific RTHN129 support (#941)
  * Changed Use battery_ok instead of battery for newmodel
  * Changed Update battery_low, temperatureN keys
  * Changed Normalize odd general keys on devices (#1010)
  * Fixed Efergy-e2 current reading exponent
  * Added FS20 remote decoder (#999)
  * Added SoapySDR general keyword settings option
  * Added option to select antenna on SoapySDR devices (#968)
  * Fixed CF32 loader; added CS8, CF32 dumper
  * Added ASAN to Debug builds
  * Changed tfa_twin_plus_30.3049: Add mic to output
  * Added new model keys option
  * Enhanced Kedsum, S3318, Esperanza with MIC (#985)
  * Added support for XT300/XH300 soil moisture sensor (#946)
  * Changed Schrader unit from bar to kPa
  * Added report model description option (#987)
  * Added native scale for SDRplay
  * Added Chungear BCF-0019x2 example conf
  * Changed GT-WT-02 to support newer timings; changed model name
  * Added pulse data text file support (#967)
  * Added Digitech XC0346 support to Fine Offset WH1050 (#922)
  * Added bitbuffer NRZI(NRZS/NRZM) decodes
  * Added Rosenborg/WH5 quirk to Fineoffset
  * Added support for Silverline doorbells (#942)
  * Changed TPMS Toyota to match shorter preamble
  * Changed TPMS Citroen data readings
  * Changed TPMS Renault data readings
  * Added Digitech XC-0324 temperature sensor decoder (#849)
  * Added sample rate switching
  * Added Mongoose
- Remove patch:
  * rtl_433-disable-test.diff
* Sat Aug 18 2018 mardnh@gmx.de
- Update to version 18.05+git.20180806:
  * Clean up copyright notes
  * Change flex to more robust opt arg parse
  * Fix bitbuffer_parse to be sane about empty row specs
  * Tweak timings for Kerui
  * Fill id string for Bresser device.
  * Add battery event for Kerui
  * Update style for chuango
  * Update style for akhan
  * Update style and add cmds to Kerui
  * Update code style for wssensor
  * Add Hyundai WS SENZOR (#779)
  * Add fix for TEK377E, issue #776
  * Fix Makefile devices to match CMakeLists
  * Add CS16 input and output (#773)
  * Add device: M-Bus (EN 13757-4) - Data Link layer (#768)
  * Fix for Autotools
  * Rewrite debug_mode to load_mode and dump_mode
  * Fix typo
  * Fix indents
  * Clean up baseband, optimize FM, add baseband-test (#770)
  * Rewrite ambient_weather for robustness and style
  * Remove some unwanted BITBUF_COLS uses
  * Change radiohead to unify the applications
  * Fix Sensible Living merge
  * Sensible Living protocol added. (#742)
  * Fix SOCKET(_TYPE) for syslog
  * Win32 syslog client patches (#762)
  * Make printout aligned (#761)
  * Make the frequency setting clearer. (#760)
  * Add real protocol number to startup output (#744)
  * Convert intertechno to data_make (#726)
  * see #755
  * FineOffset WH0530: Add battery low detection, correct rain factor (#765)
  * Add prototype for 'nice_freq()' (#759)
  * Add a "pretty-printer" of a frequency (#758)
  * No "Variable Length Arrays" for MSVC (#755)
  * Remove <strings.h> (#756)
  * More MSVC fixes (#754)
  * [MSVC] patch include/data.h (#753)
  * Include <stdlib.h> (#752)
  * Add support for Oregon Scientific UVR128 UV sensor (#738)
  * Update code style for RadioHead
  * DSC Sensors break out status bits
  * acurite_986: fix temperature type to enable conversion feature to work
* Fri Jun  1 2018 mardnh@gmx.de
- Update to version 18.05+git.20180525:
  * New devices: Euroster 3000TX, Elro DB270 (#683)
  * Add flex spec for Byron BY doorbells (#686)
  * change array separator in csv to ";" otherwise RadioHead ASK output will break csv parsers (#687)
  * create flex dev adhoc and enable csv output (#688)
  * calc stop_time late; better exit messages (#689)
  * add proper reset and gap limit to Quhwa; use repeated rows; add csv output; style update (#691)
  * fix short char buffer
  * Adding interlogix devices driver (#649)
  * fix bitbuffer_extract_bytes clipping unaligned bits
  * fix Interlogix; style
  * Added decoder for Dish Network UHF Remote 6.3 (#700)
  * use actual max protocols
  * Update acurite.c (#704)
  * Acurite 06045M structured data (data_make) cleanup, decoding improvements. (#707)
  * Adjust alarm from 1 second to 3 second
  * Acurite 986 convert to JSON/data_make * Add hack from my branch to work around missing bit
  * Fix typos/misspellings
  * Add conversion hPA/inHG, kPa/PSI (#711)
  * Fix acurite raw_str termination
  * Touch up waveman code style, add missing time field
  * Add PiWM decoding (#724)
  * SimpliSafe Sensor (#721)
  * SimpliSafe style updates
  * Add Pacific PMV-C210 TMPS support (#717)
  * Add preamble option to flex decoder
  * Make intertechno decoder work with ITT-1500 (#694)
  * Convert DSC to structured data (#725)
  * Regularize and extend Acurite 6045M comments (#728)
  * DSC data_make additions. (#730)
  * Indents
  * Acurite TXR/6045 fixes
  * Acurite cosmetics fixes
* Mon Feb 26 2018 mardnh@gmx.de
- Create subpackge for header files
* Thu Feb 15 2018 mardnh@gmx.de
- Update to version 0.0.1+git.20180213:
  * fix flex options, add gap_limit for PWM
  * README.md: Add another Debian dependency (#680)
  * README.md: Fix typo (#679)
  * README.md: Add build tools to Debian command (#678)
  * revert localtime_r to localtime for win32
  * disable syslog output on win32
  * remove left over xc0348 device
  * Fix on_connect signature and topic subscriptions in MQTT examples. (#674)
  * refactor hostport_param
  * refactor abuf
  * allow ipv6 for syslog
  * add flex device to Makefile
  * refactor print_array_value
  * use prettier C99 bool macro
  * shuffle functions
  * change aux pattern to composition
  * remove output_hander_t, printer_ctx indirection
  * change indent; consistent style
  * adds a remote syslog output
  * update readme usage info
  * default enable x10_sec, timing doc, style
  * Adds x10_sec device for decoding X10 Security RF signals (#671)
  * Spelling fix: gague -> gauge (#672)
  * fix new_template
  * use localtime_r instead of localtime
  * reduce false positves with Bresser on LaCrosse TX141TH
  * add MIC to bresser
  * freshen up template with more examples
  * add a flexible general purpose decoder (#647)
  * remove PWM_TERNARY, use PWM_PRECISE for sync bits
  * change pulse_detect to use pwm_precise for sync bits
  * rename CLOCK_BITS to DMC
  * change fordremore to proper DMC, the output is vastly different
  * change DMC (clock_bits) demod to add rows on symbol errors
  * convert Acurite 592TXR from TERNARY to PRECISE
  * reduce false positives in Thermopro TP12
  * code style for LaCrosse TX141
  * convert LaCrosse TX141 from TERNARY to PRECISE
  * convert Bresser 3CH from RAW to PRECISE
  * convert LaCrosse TX from RAW to PRECISE
  * convert Philips Sensor from TERNARY to PRECISE
  * convert Calibeur from TERNARY to PRECISE
  * convert Acurite 00275rm from TERNARY to PRECISE
  * enhance pwm_precise to cover raw and ternary cases
  * add sync pulse count to bitbuffer
  * fix Lacrosse TX141TH sync rows
  * Added device LaCrosse TX141 support to lacrosse_TX141TH_Bv2.c (#670)
  * add back C99 with ADD_DEFINITIONS
  * C99 compatibility (#667)
  * add git version info to usage output if available
  * let cmake set C99; CMP0025
  * additional build deps (#668)
  * wh1080: Fix warning about uninitialized use (#666)
  * adding asepc, getkwargs helper
  * fold PWM_precise_parameters into r_device
  * output pulse_demod_pwm_precise at end of pulses as well
  * adapt precise param sync width to us
  * use _XOPEN_SOURCE on string.h for strdup
  * fix -R 0 fault
  * use bitbuffer_clear for bitbuffer_parse
  * refactor bitbuffer_parse
  * minor
  * Doxygen EXTRACT_ALL to show all docs, there isn't any notable exported API yet
  * update 1.7 Doxyfile to 1.8
  * add Doxygen building to CMake
  * cleanup
  * parse number suffixes on e.g. frequency, samplerate, duration, hoptime
  * relax false positive logic prologue/alecto to allow a single leading pulse
  * Fix unit conversions for Acurite 5n1 (#651)
  * fix `-d n` parsing
  * Add missing brand to OSv1 (#650)
  * adding FindGperftools cmake module
  * add Profile build type using GPerfTools
  * use CMake defaults for optimizations (-O3)
  * RTGN129 author name (#646)
  * change grab file name to gNNN_FFFM_RRRk.cu8 (#642)
  * replace -i <serial> with -d :<serial> (#648)
  * Clean up WIN32 include/ifdef (#643)
  * fix read-mode buffer size and allocation, s. #641 (#644)
  * reduce Alecto/Auriol-v2 false positives in Prologue
  * enable pedantic warnings; also on Clang
  * pedantic fix: -Wextra-semi
  * pedantic fix: replace arithmetic on void* (gnu extension) with sane char* arithmetic; fix function pointer for qsort, bsearch
  * adding mic to OS SL109h
  * remove false positives with wg-pb12v1, please report samples if WH2, WH5, Telldus are missing messages
  * remove debug from wg-pb12v2; add mic to fineoffset
  * fix GE Color Effects Remote indent and MAX_PROTOCOLS
  * chmod 644 on source files
  * add model switch to WH2/WH5/Telldus in fineoffset
  * Add support for Telldus variants of fineoffset (#639)
  * merge formatting from PR #615
  * disable mebus: lacks docs, tests and has false positives
  * Esperanza, Kedsum, S3318p: relax reset timing, check sync pulses to remove dups
  * fix OOK_PULSE_CLOCK_BITS pulse_tolerance to µs
  * fix: require 24 bits data for rain gauge sensors
  * Update chuango.c
  * Stop after outputting successful event(s)
  * Added support to Oregon Scientific RTGN129
  * Add device NEXA LMST-606 magnetic sensor
  * added unit (Fahrenheit) to output of Ambient Weather Temperature Sensor
  * Update rtl_433.h
  * fixed compile time warnings (formatting related)
  * change PWM_Precise_Parameters pulse_tolerance to use us instead of samples
  * fixing schraeder data types
  * Remove unintended spurious white spaces
  * Add another schrader TPMS support (corrections)
  * Add another schrader TPMS support
  * remove spurious if-statement
  * Specify device to use via serial number
  * automatically use first available dongle
  * define _GNU_SOURCE for strdup
  * Add support for the Thermopro TP-12.  This is based heavily on the code for the Thermopro TP-11, and the modulation is compatible, but the bit layout is fairly different and there are more sensors, so I've made this a separate device.
  * Addressed code review by @zuckschwerdt
  * Device handler for GE Color Effects remote control Fixes #569
* Wed Nov  1 2017 mardnh@gmx.de
- Update to version 0.0.1+git.20171101:
  * Add support for Philips outdoor temperature sensor
  * move fprintf call when timer expires
  * remove check for DEFAULT_HOP_EVENTS
  * fix edge-case where bytes_to_read is equal to length of bytes read
  * Fix output formatting
  * Added support for Ford car remote.
  * Removed unused code and variables.
  * Added a ford car remote decoder for the Fiesta and CMAX. device id is a rolling id number that seems to have approx 64 variations. The meaning of the code fields has not been determined.
  * Fixed output formatting for JSON and csv
  * Added decoding of X10 CR12A ON/OFF remote commands
  * Add support for FT-004-B
  * Make LaCrosse TX141TH sensors return temperature_C so that they are more consistent with other temperature sensors (#606)
  * Acurite Rain Gague emit structured data
  * shortend model string to Inovalley kw9015b
  * added json-support and description for TFA 30.3161 rain sensor
  * Fixed do_build.sh: forgot to do 'cd ..' before cloning rtl_433_tests.git
  * Fixed do_build.sh, .travis.yml trying to run 'make test'
  * Added tests from rtl_433_tests.git repo
  * Fixed do_build.sh: don't 'make installe'
  * Fixed .travis.yml: 'sudo: required', 'dist: trusty'
  * Fixed .travis.yml: added sudo, added apt.sources
  * Fixed permissions on do_build.sh
  * Added draft of .travis.yml, do_build.sh
  * Use default number of buffers to fix crash of two rtl_433 instances
  * don't restart the timer if we are aborting anyway; cancel timer on rtlsdr_cancel_async
  * fix unknown `uint` type; whitespace fixes
  * add merbanan changes
  * add suggested optimisation
  * suggested changes
  * remove test
  * add infactory sensor
  * bitbuffer: Handle row overflow a bit more gracefully
  * pulse_analyzer: Add detection of PWM with multiple packages
  * explaining dipswitch 2 meaning
  * message validation fix
  * shortening output
  * changes after pull request
  * Switched to new data API
  * adding Renault TPMS sensor
  * adding Ford TPMS sensor
  * Add option to verify simulated decoding of raw data
  * reduce false positives by rejecting 0x000000 / 0xffffff
  * adding Toyota TPMS sensor
  * reduce false positives, require at least 5 repeats
* Sat Jul  8 2017 mardnh@gmx.de
- Update to version 0.0.1+git.20170708:
  * prevent bad messages of all 1 that falsely check ok with crc.
  * adding IBIS beacon
  * fix Company name, output flags and tire pressure/temperature
  * proper units for pressure, units for power, fix OS output fields
  * adding Oil Ultrasonic Standard protocol
  * hop interval param added (multiple frequencies)
  * updated README.md
  * typo fix
  * pipe symbol with HTML code
  * Update README.md
  * Added data struct for efergye2 (#540)
  * fix fabsf() in integer context (#551)
  * adding Citroen TPMS device
  * bugfix, bitbuffer needs to be initialized
  * adding Oil Ultrasonic STANDARD using ASK on 915MHz
  * Honda remote: fix an out of bounds array access
  * Removed use of pow() (#557)
  * Possible bugfix for issue #136
  * Update .gitignore
  * Fix hex output padding for unit ID field for lightwaverf.
  * Thermopro TP-11.
  * Move TP-11 to the end.
  * Thermopro TP-11 changes:   - exit early if not enough matching rows are found   - simplify bits_per_row check   - local_time_str happens after decoding data
  * Fix sign error.
  * Variable declarations are at the top of the function.
  * Solight TE44 wireless thermometer
  * Fix spelling in documentation
  * adding Wireless Smoke and Heat Detector GS 558
  * adding Generic off-brand wireless motion sensor and alarm system
  * remove false positives from Esperanza/Kedsum
  * replace binary literals with hex
  * fix misc typos and reduce efergy false positives
  * allow WH2 to miss the first sync bit for WH5 support
  * reject false positive and fix wrong field index and minimum bit count
  * fix compiler warnings; possible undef bug; signed/unsigned
* Mon May 15 2017 mardnh@gmx.de
- Update to version 0.0.1+git.20170515:
  * Add files via upload
  * Add support for Fine Offset WH3080 weather station
  * Updated "quadrant" code for WGR968
  * Restored 'static' variables
  * Bump MAX_PROTOCOLS to 78
  * cleanup: replacing broken sprintf, removing debug code
  * fix short buffer: sprintf's output is always null-terminated
  * adding output redirection to files
  * Sensor GT-WT-02 Change REDME.md
  * fix sample_file_pos to actually count seconds, each sample is 16 bits (I+Q uint8's)
  * change data output fields to usual order
  * add missing "model" data output
  * add time to data output
  * Add support for Vaillant calorMatic 340f (VRT 340f) wireless central ceating control (868MHz)
  * adds a watchdog timer to async callback, abort if async events stop arriving
  * improving compatibility for Renkforce DM-7511
  * Vaillant_vrt340f.c: Fix indentation, only whitespace changes
  * remove synthetic fahrenheit output. use `-C customary` to convert.
  * harmonize device data output to model instead of device or make, and crc instead of checksum
  * changing "crc", "checksum" to "mic"
  * delete stray trailing whitespace
  * normalize indentation to 4 spaces or one tab, depending on prevalence in each file
  * Update rtl_433.h
* Sat Apr 15 2017 mardnh@gmx.de
- Reenable parallel build
* Thu Apr 13 2017 mardnh@gmx.de
- Update to version 0.0.1+git.20170409:
  * Include humidity field in CSV format for TX29DHT temperature and humidity sensor. (#486)
  * Fix parse error on ARM compiling with GCC due to lack of parens. (#490)
  * Don't convert channel 4 to 3 for the sensor Oregon THGR810 (#489)
  * Fine Offset W25 Temperature/Humidity/Pressure sensor (#492)
  * Device for cheap probes where the PCB is marked WG-PB12V1.
  * Revert "Update pulse_detect.c" (#493)
  * MQTT: Add example to README and Python test client (#495)
  * Pulse Analyzer: Add 'Include only' mode (#497)
  * Fine Offset WH0530: Add new device
  * DSC: Make less noisy
  * pulse_demod: Make pwm_precise resilient to short spurious pulses
  * Acurite 6045, correct temperature decoding * Reduce Msg Type (status bits) to 2 remaining bits. * Remove possible lightning stats/flag bits from distance * output lightning status/flag bits separately for now * Understanding of status/message type bits still a WIP.
  * Acurite 06045 add docs, refactor decode out of txr_callback
  * acurite 6045, remove unnecessary variable
  * Added code for differing impules to KWH values
  * LaCrosse TX6/7 cleanup
  * LaCrosse TX6/7 reindent with consistent 4 column spacing
  * Fix #503
  * Update util.c
  * Pull Request Changes ---
  * FineOffset_WH25: Add debug printout
  * FineOffset_WH25: Correct decoding of Temperature and ID
  * FineOffset_WH0530: Fix bug in ID decode
  * FineOffset_WH25: Additional bitsum check + minor fixes
  * ELV WS2000: Make it somewhat work...
  * Corrected conflict in MAX_PROTOCOLS.
  * erroneous entry in src/Makefile.am
* Thu Feb  2 2017 mardnh@gmx.de
- Update to version 0.0.1.git1486029687.074cc2f:
  * Reverse some more stray changes
  * Ensure analyzer works with auto level as default
  * Various documentation fixes for auto level
  * Acurite 6045 lightning prelim. and 609 cleanup.
  * WH1050 weather station based on WH1080 module.
  * Honeywell/Ademco Door/Window Security Sensor driver
  * Honeywell/Ademco Door/Window Security Sensor driver
  * Honeywell/Ademco Door/Window Security Sensor driver
  * Honeywell/Ademco Door/Window Security Sensor driver
  * Honeywell/Ademco Door/Window Security Sensor driver
  * Honeywell/Ademco Door/Window Security Sensor driver
  * Honeywell/Ademco Door/Window Security Sensor driver
  * Honeywell/Ademco Door/Window Security Sensor driver
  * added json/kv capbilities to Acurite tower sensor
  * added battery status as OK or LOW
  * fixes for upstream
  * fix indent
  * Update README.md
  * Added more installation step detail and troubleshooting section.
  * Correct negative temperatures
  * Danfoss CFR: Initial decoding attempt
  * Danfoss: Output data correctly
  * Danfoss: Enable driver by default
  * Danfoss: Add proper header search and make decoding byte based
  * Danfoss: Add CRC check. Remove raw printout.
  * Danfoss: Reverse engineered unknown nibble :-)
  * Danfoss: Minor cleanup and fix debug print
  * add maverick et73x BBQ sensor
  * Add crc json tag and cvs output
  * Add crc json tag
  * Update brennstuhl_rcs_2044.c
  * Spelling correction (protcols -> protocols)
  * Improved hideki.c to detect data from the wind/temperature and the rain sensor. Changed pulse_demod_clock_bits to allow a missing short gap at the end of the message which is needed for the new sensor types.
  * Increase number of protocols to 70
  * Update pulse_detect.c
  * Update acurite.c
  * Segfault on Owl CM160
  * Added support for RF-tech 433 remote temperature sensor.
  * Add rftech.c to Makefile.am to support configure/automake.
  * Added support for LaCrosse temperature/humidity sensor TX141TH-Bv2
  * Minor cosmetic changes
  * Implemented recent changes suggested by @merbanan.
  * move to new internal data format on acurite5n1
  * remove old acurite5n1 decoder, now uses acurite_txr
  * normalize temperature key
  * acurite5n1 battery status
  * correct acurite5n1 wind speed formula
  * add raw msg debug output for acurite5n1
  * acurite5n1: fix battery status
  * Stop akhan-100F14 catching things that don't belong to it
  * Add missing return 1.
  * don't mess up device ordering
  * remove old, incorrect wind direction mapping
  * output raw rain counter values, use define for msg type
  * move all units to native customary/US
  * remove another unused function
  * Removed signal quality output
  * acurite 5n1: output message sequence number
  * Add protocol definition for oregon scientific THN129 temp only sensor. (#469)
  * Support for Acurite 00275rm and 00276rm sensors (#467)
  * Fixed bug in CM160 (#474)
  * devices: mebus: Use data API for results (#475)
  * identify F007TH with both 0000000000010100 and 1111111111010100 (#481)
  * Add support for BTHGN129 (#483)
  * LaCrosse TX29-IT / TX35DTH-IT weather sensor (#479)
  * fix typo error (#484)
  * WH1050 weather station - remove unused fields from csv format. (#485)
* Mon Sep 19 2016 mardnh@gmx.de
- Update to version 0.0.1.git1474227546.2d7072a:
  * Adding support for the Bresser 3CH type sensor
  * Disable acurite rain gauge due to false positive with oregon scientific v1
  * add -T option to set run duration
  * Fixed generic_remote to utilized data_acquired_handler to support json output. Not perfectly indented, but works.
  * use binary mode to open file - fixes decoding on windows
  * Improved datetime/weather signal type detection.
  * Fix incorrect handling of negative temperatures in ambient_weather.c (#376)
  * missing backtick in readme.md, now in LF (#361)
  * New Springfield Temperature and Soil Moisture decoding (#378)
  * introduce functionality to decode the Oregon Scientific SL109H Remote Thermal Hygro Sensor (#368)
  * Added data output (for json/csv/etc.) (#380)
  * Acurite 606TX Sensor Support (#382)
  * Cleanup of Acurite 606TX code that should have been done before (#383)
  * add TFA pool thermometer support (#386)
  * Enabled low battery detection on FineOffset WH1080 (#387)
  * Add support for Kedsum Temperature/Humidity sensor (#389)
  * added support for blyss dc5-uk-wh (#391)
  * Add FSK_PULSE_MANCHESTER_ZEROBIT
  * Add initial Schrader TPMS decoder
  * Better Schraeder TPMS payload meaning
  * Add Schreader TPMS crc calculation
  * Add LightwaveRF initial driver (#394)
  * Added Steelmate TPMS support (#396)
  * Fix json output and minor rearrangement of code
  * Add template decoder skeleton
  * Add initial Elro DB286A support (#398)
  * Elro DB286A: Correct id_string array length (#399)
  * Updated README for new efergy_optical sensor and missing recent devices.
  * Add CRC16-CCITT function
  * Change to new output system
  * Add brand parameter to data output format
  * Add sensor WGR968 parser support
  * Add Handling of error packet format
  * Smell and Fix some bad code
  * Changed CRC calculation to use new function in util.h no longer using lib_crc
  * added file output support and changed energy to power. only output crc values when using -D argument.
  * Only output crc when using -D argument
  * I have kept the crc calculation to be the first 10 bytes. Bytes 11 and 12 are the CRC16_CCITT. The only puzzle left is why does the last byte does as it sometimes change to 80.
  * Efergy Optical device added. Multiple changes to combine several files into one commit.
  * Removing lib_crc files
  * efergy_optical with CRC checks (#400)
  * Honda Key Remote
  * formatting changes
  * Fix review errors,using Kdiff3 to compare the code
  * Fix build
  * Honda remote key fob, decodes which button has been pressed.
  * Honda Keyfob changes
  * Added Honda Remote decoder.
  * Added Honda Remote
  * Fixed to include Honda remote any my deletion of the README.md when trying to fix git conflicts.
  * Changed author name at the top of the file, removed fprintf that was not behind if debug statement. Added a validater to check that number of bits are 386.
  * Changed and fixed validation code to suit varying bits per row. Lock command has 394 bits whereas other commands only has 386 bits per row. (#405)
  * Add THN802 and PCR800a to oregonscientific.c (#410)
  * unbreak the build (#411)
  * add battery status (low or ok) to F007TH ambient weather devices (#414)
  * Add support for another Fine Offset sensor
  * Convert Acurite "TH" (609TXC) to use data_make * Existing Acurite "TH" sensor now labeled as 609TXC * Use data_make() for JSON, CSV, KV output * minor code cleanup/reorg
  * Add RadioHead ASK device
  * Add option to register all devices
  * Fix MAX_PROTOCOLS when enabling all devices
  * acurite: disable all old api devices by default
  * ambient_weather: fprintf cleanup
  * brennstuhl_rcs_2044: disable all old api devices by default
  * cardin: disable all old api devices by default
  * danfoss: disable all old api devices by default
  * dsc: disable all old api devices by default
  * ec3k: disable all old api devices by default
  * efergy_e2_classic: disable all old api devices by default
  * elv: disable all old api devices by default
  * gt_wt_02: disable all old api devices by default
  * inovalley-kw9015b: disable all old api devices by default
  * intertechno: disable all old api devices by default
  * lacrosse: fprintf cleanup
  * lacrossews: fprintf cleanup
  * lightwave_rf: disable all old api devices by default
  * mebus: disable all old api devices by default
  * new_template: fprintf cleanup
  * silvercrest: disable all old api devices by default
  * steffen: disable all old api devices by default
  * valeo: disable all old api devices by default
  * x10_rf: disable all old api devices by default
  * Use built in CRC functions
  * Fix indent (RH ASK)
  * Declare variables at the begining (RH ASK)
  * Add CRC=OK (see #416) & fix syntax error (RH ASK)
  * Fix debug output (RH ASK)
  * fprintf fixup
  * Add device debug output
  * Added support for Kerui PIR sensor
  * Fixes
  * Cleanup related to devices disabled by default.
  * new_template rework
  * Make auto level limit the default
* Sun Mar 27 2016 mardnh@gmx.de
- Update to version 0.0.1.git1459106482.900fca7:
  + use uintptr_t instead of unsigned long - fixes build error on win64
  + fix: change doc comments from "samples" to "us"
  + clean up casts regarding C Integer Promotions
  + Oregon Scientific V1 Decoding
  + add -U option to print timestamps in UTC
  + Support for Proove
  + Adjust pulse_tolerance to get all sensors to work
  + Update calibeur rf104 to new data api
  + add missing usage documentation for -n parameter: number of samples to read before quitting
  + add -T option to set run duration
  + Prevent crash when no output file is given with `-S`
  + Fineoffset: Fix key/value printout
  + pulse_analyzer: Add PCM detection
  + Revert "add -T option to set run duration"
  + Calibeur: Fix key/value printout
  + pulse_demod_osv1: Only print preamble info when debugging
  + Fix https://github.com/merbanan/rtl_433/issues/347
  + use uintptr_t instead of unsigned long for the remaining devices
  + mingw32 does not have setenv
  + Remove spurious execute permission from README.md
* Fri Mar 11 2016 mardnh@gmx.de
- Update to version 0.0.1.git1457694384.7ab14a4:
  + Added support for Fine Offset WH1080 weather station. Merging with Digitech XC0348 (it's a rebranded WH1080).
  + Adding support for Fine Offset WH1080.
  + Update fineoffset_wh1080.c
  + Added support for Fine Offset WH1080
  + Add remote control on chip HT680
  + Rethinking algorithm
  + fix decoders for WGR800 & THGR810 add decoder for PCR800
  + adding a bitbuffer_find_repeated_row() with examples how it simplifies device code
  + code cleanup
  + starting to migrate to data_make
  + only try the crc if the packet would match
  + adding battery indicator for Nexus
  + add labels for ambient_weather.c to match oregon_scientific.c printout
  + Update README.md
  + Added tristate coding.
  + Correction data types in bitbuffer_find_repeated_row()
  + new feature: allow multiple outputs (WIP)
  + Decode device id from current_cost, and support more devices
  + Add support for Conrad S3318P
  + s3318p: use native temperature format
  + Add support for Conrad S3318P
  + also switch the labels on output conversion
  + Spurious output for debug mode
  + Remove some compiler warnings
  + fix wind direction nibble extract for WGR800
  + Remove some compiler warnings
  + Remove some compiler warnings
  + fix off-by-one and make the null explicit
  + LaCrosse WS-2310 json output
  + Fixed WS-2310 json gust_speed to gust_speed_ms
  + Fix some memory leaks
  + TFA Twin Plus 30.3049 json support
  + Output less decimal places to get rid of bogus digits
  + Update fineoffset_wh1080.c
  + Switched to new data API
  + Update generic_temperature_sensor.c
  + KlikAanKlikUit json support
  + Added data labels for KlikAanKlikUit output
  + Added Akhan 100F14 RKE system
  + Updated akhan_100F14 message passing
  + Update CM180 Energy Sensor code - Add Checksum and new output system format
  + Many sensor required a larger pulse tolerance
  + Add Quhwa doorbell support
  + Clearer code
  + Add support for Quhwa doorbell
  + Support for Quhwa doorbell
  + data_make output for chuango
  + Update device support
  + add missing quhwa.c reference
* Thu Feb  4 2016 mardnh@gmx.de
- Update to version 0.0.0.git1454367220.e7bc33d:
  + Auto level: Increase sensitivity to low signals
  + FSK: Change FM demodulation to use integer atan2()
  + Pulse_detect: Increase maximum number of pulses
  + FSK: refactor FSK into own function for sanity
  + Auto level: Make OOK level estimators a bit slower
  + add a converter for cf32 (gnuradio output format)
  + Convert Alecto to Pulse decoder
  + Convert Inovalley to Pulse decoder
  + Convert Nexus to Pulse decoder
  + Convert Generic temperature sensor to Pulse decoder
  + Convert Steffen to Pulse decoder
  + Convert Mebus to Pulse decoder
  + Convert Intertechno to Pulse Decoder
  + Convert Newkaku / KlikAanKlikUit to Pulse decoder
  + Convert Acurite to Pulse decoder
  + Convert ELV to Pulse decoder
  + Remove last sample based decoder OOK_PWM_D
  + Remove OOK_PWM_D: Clean-up header
  + Fix: Segmentation Fault in cf32 file support
  + Update Wiki with new options
  + only treat samples as cf32 when mode==3
  + minor changes to support (cross-)compilation with MinGW
  + newkaku: support APA3-1500R
  + remove superfluous prototype
  + fix loop syntax
  + ignore buffers of all zeros.
  + rewrite LaCrosse TX output to data fields
  + adding data_make for humidity
  + typo
  + fix: broken bit operation
  + Make quiet mode output at least test file name
  + FSK: Change to F1/F2 estimation instead of F1/Fdelta
  + emonTx: Add stub driver
  + FSK: Increase initial frequency threshold
  + Change pulse data from unsigned to int to avoid undefined behaviour
  + fix limits for decoder
  + [xc0348] Add CRC validation
  + [xc0348] Don't filter on device id
  + [xc0348] Fix temperature (top nibble doesn't belong)
  + Include stdio for FILE
  + [xc0348] Add json output
  + [xc0348] Add csv fields
  + FSK: Fix data is not cleared at End Of Package
  + FSK: Fix for handling pulse overflow correctly
  + new command line option `-C native|si|customary` that hooks into `data_acquired_handler` and if `si` and type is DATA_DOUBLE and key is temperature_C then celsius2fahrenheit, if `customary` and type is DATA_DOUBLE and key is temperature_F then fahrenheit2celsius. Also if there is a FORMAT the last character "C" / "F" will be switched accordingly.
  + Emontx: Correct for sample frequency of 2.5 MHz
  + FSK: Rework to make pulse polarity absolute (pulse = high frequency)
  + bitbuffer: Add function to invert bits
  + current_cost: Invert bits to compensate for absolute FSK
  + FSK: correct comment
  + FSK: Fix slow estimation at initial frequency
  + Convert decoder limits to float instead of int, to allow more precision
  + elv: Fix precision of bit limits
  + rubicson: Fix precision of bit limits
  + Switch protocol decoder limits to µs instead of "samples at 250000Hz"
  + ec3k: Fix precision of bit limits
  + valeo: Fix precision of bit limits
  + dsc: Fix precision of bit limits
  + current_cost: Fix precision of bit limits
  + Add bitbuffer_extract_bytes() function for accessing unaligned data
  + Add crc16() function
  + Finish implementing emontx driver
  + Change bit limits in r_device structure to float too
  + Pulse detect: Make low level (noise) estimator even slower
  + Pulse detect: supress spurious short gaps
  + Pulse detect: Minor renaming for consistency
  + Pulse analyzer: Print absolute timing
  + Pulse analyzer: Print FSK frequencies
  + Pulse analyzer: Print OOK carrier frequency
  + Migrate fineoffset to new data format and add support for TFA 30.3157 Temperature sensor
  + Fix building with autotools
  + Migrate nexus to new data format and add support for Technoline TX 9116 Temperature sensor
  + fineoffset: fix typo (unbreak humidity sensor)
  + fix: missing NULL terminator
  + fix: use fabsf() instead of abs()
  + emontx: Increase size of words[] array for endianness conversion
  + alecto: only accept 36 bit packets
  + rubicson: only accept 36 bit packets
  + oil_watchman: Return events count
  + emontx: Return events count
  + rubicson: switch to new data api
  + change output of -F kv to resemble the custom fprintf output of the decoders
- add patch rtl_433-disable-test.diff to disable build-time-tests for now
* Sun Jan  3 2016 mardnh@gmx.de
- Update to version 0.0.0.git1450346637.879b467:
  + Add support for new demodulation
  + Add support for WT450 devices
  + Fix automake builds Update source file list and set compiler in C99 mode
  + rubicson: implement crc and other parameters
  + nexus: clean up the nexus protocol
  + WT450: Better packet detection, battery indicator
  + WT450: Add missing the supported device label in README file.
  + New Lacrosse Weather Station Decoding
  + Added Esperanza EWS
  + LaCrosse Weather Station WS-2310TWC changes
  + Updated decoding of Lacrosse Weather Station
  + DSC Security Contact added CRC-8 calc/check * Added "little-endian" CRC-8 calculation * Moved reverse8() to util.c * Quieted WT450 callback false positive messages
  + Updated crc8 to take initial CRC value as a parameter
  + Read data from stdin with '-'
  + Added quiet mode (-q) to suppress non-data related messages
  + Lacrosse Weather Station Decoding cleanup
  + Added missing wt450.c for autoconf compile
  + Minor documentation update
  + Include the last sample when saving samples between filter runs
  + Share memory between fm buffer and temporary buffer
  + Add support for Efergy e2 classic
  + Remove unused command line argument 'c' (used to be decimation level)
  + Only allocate synchronous read buffer if synchronous reads are used
  + WT450: Fix parity computation, error messages only in debug mode
  + add Inovalley kw9015b rain and temperature weather station
  + add new noname wireless wheather station
  + fix makefile.am
  + change r_device->name from ""KW9015B Transmitter" to "Inovalley kw9015b rain and Temperature weather station"
  + rename source / callback generic_temperature_sensor
  + rename r_device->name from "RF Wireless Temp Transmitter" to "Generic temperature sensor 1"
  + Acurite 592TXR Temperature/Humidity Sensor
  + Acurite 592TXR Temperature/Humidity Sensor
  + Updated README.md with new device numbers
  + Acurite 986 Refrig/Freezer Temp initial support
  + Acurite 986, add CRC check, fix negative values
  + Acurite 986 low battery detection
  + Inovalley kw9015b : fix negative temperature
  + General structural data support for generating (ie.) JSON
  + Generic temperature sensor 1 : fix negative temperature
  + Add support for RTGN318
  + Correct indentation
  + data: provide a key-value-printer
  + data: added formatting support
  + rtl_433: added JSON support
  + wt450: use JSON output instead of fprintf
  + data: introduce auxiliary data as an argument
  + data: only format key-value-format, not JSON
  + data: added CSV support
  + rtl_433: added CSV support. Requires driver support.
  + wt450: added CSV support (provide .fields)
  + waveman: added structured data support
  + Fix compilation with autotools
  + util: Make comment consistent
  + util: Fix mismatched comment
  + ambient: Migrate to using common method for output
  + Updated README.md
  + Migrate "prologue" to new output handler
  + Prevent data files from being overwritten
  + README.md documentation updates
  + README.md space to fab fix for consitency * fix table markdown typo
  + waveman: added missing comma to fix CSV output
  + data: fixed the filtering of CSV fields
  + Convert Waveman to pulse decoder
  + Changed acurite 5n1 to use pulse demodulator
  + Convert Silvercrest to use pulse demodulator
  + Remove pwm_p_decode() and OOK_PWM_P
  + Convert from GNU to C99 syntax
  + Update alecto driver to new "data" format
  + Update oregon_scientific driver to new "data"
  + Fix indentation
  + Fix missing comma
  + Add Hideki TS04 sensors
  + Support framed FSK Manchester decoding compatible with Si4320/RFM01
  + Add Watchman Sonic ultrasonic oil tank monitor
  + Add heuristic for detecting RFM01-framed FSK
  + hideki: Remove overzealous warning about invalid parity
  + Add bitbuffer_search() and bitbuffer_manchester_decode() functions
  + Convert oil_watchman to bitbuffer_search() + bitbuffer_manchester_decode()
  + Revert "Support framed FSK Manchester decoding compatible with Si4320/RFM01"
  + Add Watchman to readme
  + Add CurrentCost TX device
  + Fix indent + TODO (minor for CurrentCost sensor)
  + Fix negatif temp value for Hideki TS04
  + Use constant to define and check OS (v2) sensor_id
  + Fix channel error with some OS devices
  + Do not require first byte of Watchman packets to be 0x28
  + Update Readme.md
  + Sync usage messages and README.md
  + README improvements, added typical command line * rtl_433: better description of ppm error option
  + Added -W to overwrite files
  + Added -W to README.md
  + Auto level - initial implementation
  + Auto level - suppress spurious initial pulses
  + FSK spurious short pulse suppression
  + Auto level - print level in analyzer
  + Fix to read complete file
  + Pass 0 into local_time_str() for current time instead of using time()
  + When reading sample files, make local_time_str() show offset not time of day
  + Add temperature output in °C to Watchman decode
  + Auto level - minor fixes
  + Improve comment about level estimates
  + Fix automake build
  + Sort source file lists in CMakeLists.txt and Makefile.am
* Sun Sep 27 2015 mardnh@gmx.de
- initial package
